@@ -5,9 +5,9 @@
 //! These callbacks can R/W the data from a stream(Blocking) or only R the data(Non-Blocking).
 //!```
 //!pub trait HandlerCallbacks {
-//!    fn ds_b_callback(&self, _in_data: Vec<u8>) -> CallbackRet {CallbackRet::Relay(_in_data)}
+//!    fn ds_b_callback(&mut self, _in_data: Vec<u8>) -> CallbackRet {CallbackRet::Relay(_in_data)}
 //!    fn ds_nb_callback(&self, _in_data: Vec<u8>){}
-//!    fn us_b_callback(&self, _in_data: Vec<u8>) -> CallbackRet {CallbackRet::Relay(_in_data)}
+//!    fn us_b_callback(&mut self, _in_data: Vec<u8>) -> CallbackRet {CallbackRet::Relay(_in_data)}
 //!    fn us_nb_callback(&self, _in_data: Vec<u8>){}
 //!}
 //!```
@@ -41,7 +41,7 @@
 //!     }
 //! 
 //!     // DownStream blocking callback (Read & Write)
-//!     fn ds_b_callback(&self, _in_data: Vec<u8>) -> CallbackRet {
+//!     fn ds_b_callback(&mut self, _in_data: Vec<u8>) -> CallbackRet {
 //!         println!("[CALLBACK] Down Stream Blocking CallBack!");
 //!         CallbackRet::Relay(_in_data)
 //!     }
@@ -52,7 +52,7 @@
 //!     }
 //! 
 //!     // UpStream blocking callback (Read & Write)
-//!     fn us_b_callback(&self, _in_data: Vec<u8>) -> CallbackRet {
+//!     fn us_b_callback(&mut self, _in_data: Vec<u8>) -> CallbackRet {
 //!         println!("[CALLBACK] Up Stream Blocking CallBack!");
 //!         CallbackRet::Relay(_in_data)
 //!     }
@@ -70,8 +70,8 @@
 //!             bind_port: "443".to_string(),
 //!             remote_host: "remote.com".to_string(),
 //!             remote_port: "443".to_string(),
-//!             ssl_private_key_path: "./remote.com.key".to_string(),
-//!             ssl_cert_path: "./remote.com.crt".to_string(),
+//!             ssl_private_key_path: Some("./remote.com.key".to_string()),
+//!             ssl_cert_path: Some("./remote.com.crt".to_string()),
 //!         })
 //!     );
 //!     // Start listening
@@ -176,8 +176,8 @@ pub struct RelayConfig {
     pub bind_port: String,
     pub remote_host: String,
     pub remote_port: String,
-    pub ssl_private_key_path: String,
-    pub ssl_cert_path: String,
+    pub ssl_private_key_path: Option<String>,
+    pub ssl_cert_path: Option<String>,
 }
 
 /// CallbackRet for blocking callback functions
